#
# spec file for package jacktrip
#
# Copyright (c) 2021 SUSE LLC
# Copyright (c) 2012 Pascal Bleser <pascal.bleser@opensuse.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           jacktrip
Version:        1.4.0
Release:        bp154.1.48
Summary:        Multi-machine network music performance over the Internet
License:        MIT
Group:          Productivity/Multimedia/Sound/Utilities
URL:            https://github.com/jcacerec/jacktrip
Source:         https://github.com/jcacerec/jacktrip/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  gcc-c++
BuildRequires:  meson
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(Qt5Core)
BuildRequires:  pkgconfig(Qt5Gui)
BuildRequires:  pkgconfig(Qt5Network)
BuildRequires:  pkgconfig(Qt5Widgets)
BuildRequires:  libqt5-linguist
BuildRequires:  pkgconfig(alsa)
BuildRequires:  pkgconfig(jack)
BuildRequires:  rtaudio-devel

%description
JackTrip is a system used for multi-machine network performance over the
Internet. It supports any number of channels (as many as the
computer/network can handle) of bidirectional, high quality, uncompressed
audio signal streaming.

%prep
%setup -q

%build
mv build .build
%meson
%meson_build

%install
%meson_install

%files
%doc README.md
%license LICENSE.md
%{_bindir}/jacktrip
%{_datadir}/applications/*
%{_datadir}/metainfo/*
%dir %{_datadir}/icons/hicolor/48x48
%dir %{_datadir}/icons/hicolor/48x48/apps
%dir %{_datadir}/icons/hicolor/scalable
%dir %{_datadir}/icons/hicolor/scalable/apps
%dir %{_datadir}/icons/hicolor/symbolic
%dir %{_datadir}/icons/hicolor/symbolic/apps
%{_datadir}/icons/hicolor/*/apps/*

%changelog
* Wed Nov  3 2021 Fabio Pesari <fpesari@tuxfamily.org>
- Updated to version 1.4.0
  * (added) optional GUI from QJackTrip
  * (added) authentication in hub server mode
  * (added) different number of sending and receiving channels
  * (added) append thread IDs to jack client names
  * (added) new patcher mechanism that doesn't delete existing
    connections
  * (added) MkDocs based documentation
  * (added) weak jack linking
  * (added) manpage
  * (added) MSVC build
  * (added) RtAudio Meson subproject
  * (added) formatting with clang-format
  * (added) static analysis with clang-tidy
  * (added) cross compilation for Windows
  * (added) flatpaks
  * (added) appstream
  * (added) automated builds and deployment for Linux, macOS and
    Windows
  * (added) macOS and Windows Installers
  * (fixed) regression in remote client name handling
  * (fixed) long jack client names   * (> 27 characters) in 1.9.11
  * (fixed) Hardcode Derived Class Names of ProcessPlugins to
    prevent undefined behavior
  * (update) QJackTrip and JackTrip are now identical
  * (update) Change helpscreen wording for --broadcast argument
  * (update) jitter buffer alternatives
  * (update) RtAudio revive
  * (update) RtAudio device selection
  * (update) build script moved to root directory
* Tue Apr 13 2021 Luigi Baldoni <aloisio@gmx.com>
- Update to version 1.3.0
  * (added) async networking in hub listener
  * (added) limiter, compressor, reverb
  * (added) examine audio delay
  * (added) jitter buffer alternatives
  * (added) broadcast output ports
  * (added) PREFIX variable for installation path
  * (added) disconnect on timeout
  * (added) SIGTERM
  * (added) simulate packet loss, jitter
  * (added) hubpatch 5, no auto patching
  * (added) jack client name length check
  * (added) scripts/hubMode/test_hub_mode_server_and_client.sh
  * (fixed) misc. typos, indentation
  * (fixed) short form IO stat options
  * (fixed) nullptr jack server name when creating jack client
  * (fixed) stop ring buffer blocking when jack has been stopped
  * (fixed) JMess handling of non-western characters
  * (fixed) closing curly brace on mJackTrip client creation
  * (fixed) Warnings
  * (fixed) remove rtaudio device and mpeeraddress msgs.
  * (fixed) signal and slot connections
  * (fixed) incorrect dependency from jacktrip_main
  * (update) RT thread priority for network I/O
  * (update) clipping to saturation
  * (update) build instructions
  version 1.2.2:
  * (added) bindPort range to reject oddball connections
  * (fixed) jack client name strings
- Switch build to meson
* Fri Aug 21 2020 Dirk Mueller <dmueller@suse.com>
- update to 1.2.1
  - (added) src/build script builds in ../builddir
  - (fixed) refactor "Master" to be "Hub"
  - (fixed) 1.2.1 correctly versioned and tagged
  1.2 (release candidate, not yet tagged)
  - (added) jack patching modes (-p) for Hub Mode server (-S)
  - (fixed) Compilation under ubuntu
  - (removed) setRealtimeProcessPriority()
  - (removed) Rtaudio mode (but still has dependencies)
  - (fixed) IPv4-mapped IPv6 addressing bug
  ...
  - (fixed) Fixed compilation for  MacOSX10.11.sdk.
  - (update) Updated to RtAudio 4.1.1, and using shared lib in linux.
* Fri Mar  9 2018 aloisio@gmx.com
- Update to version 1.1
  * (added) Support for RtAudio. Jacktrip can now be used without
    Jack
  * (added) DNS Look-up support, now one machine can have a private
    IP (but still needs to have UDP ports open)
  * (added) New port to Windows XP and Windows Vista (experimental
    and not tested for a long time, only when using jacktrip as a
    library)
  * (added) Multiclient Server (experimental and not exposed in the
    executable)
- Dropped jacktrip-1.0.5-gcc47.patch (merged upstream)
- New homepage
- Spec cleanup
* Sat May 19 2012 seife+obs@b1-systems.com
- fix build with gcc 4.7
* Sat Apr 21 2012 pascal.bleser@opensuse.org
- initial version (1.0.5+2)
